@@ -1,20 +1,23 @@
-dispbars<-function(x,y,ulim,llim=ulim,ddir="y",arrow.cap=0.02,
- arrow.gap=0.02,...) {
+dispbars<-function(x,y,ulim,llim=ulim,arrow.cap=0.02,arrow.gap=NA,...) {
 
- length<-arrow.cap*par("pin")[ifelse(ddir=="y",2,1)]
- if(ddir=="y") {
-  x0<-x1<-rep(x,2)
-  arrow.gap<-arrow.gap*diff(par("usr")[3:4])
-  y0<-c(y+arrow.gap,y-arrow.gap)
-  y1<-c(y+ulim,y-llim)
+ length<-arrow.cap*par("pin")[1]
+ npoints<-length(x)
+ if(is.na(arrow.gap)) arrow.gap<-strheight("O")/1.5
+ for(i in 1:npoints) {
+  if(arrow.gap >= ulim[i] * 0.9 || arrow.gap >= llim[i] * 0.9) {
+   x0<-rep(x[i]-length,2)
+   x1<-rep(x[i]+length,2)
+   y0<-rep(c(y[i]-llim[i],y[i]+ulim[i]),2)
+   y1<-rep(c(y[i]-llim[i],y[i]+ulim[i]),2)
+   segments(x0,y0,x1,y1,...)
+  }
+  else {
+   x0<-x1<-rep(x[i],2)
+   y0<-c(y[i]+arrow.gap,y[i]-arrow.gap)
+   y1<-c(y[i]+ulim[i],y[i]-llim[i])
+   arrows(x0,y0,x1,y1,length=length,angle=90,...)
+  }
  }
- else {
-  y0<-y1<-rep(y,2)
-  arrow.gap<-arrow.gap*diff(par("usr")[1:2])
-  x0<-c(x+arrow.gap,x-arrow.gap)
-  x1<-c(x+ulim,x-llim)
- }
- arrows(x0,y0,x1,y1,length=length,angle=90,...)
 }
 
 brkdn.plot<-function(vars,groups=NA,obs=NA,data,mct="mean",md="std.error",
