@@ -3,16 +3,22 @@
 # Remember to convert hour/minute values to hour/decimal values.
 # example: clock24.plot(rnorm(16)+3,seq(5.5,20.5))
 
-clock24.plot<-function(lengths,clock.pos,rp.type="r",...) {
+clock24.plot<-function(lengths,clock.pos,labels=NULL,label.pos=NULL,
+ rp.type="r",radians=FALSE,...) {
+ 
  npos<-length(lengths)
  # if no positions are given, spread the lines out over the circle 
  if(missing(clock.pos)) clock.pos<-seq(0,24-24/(npos+1),length=npos)
  # start at "midnight" and go clockwise
- radial.pos<-pi*(450-clock.pos*15)/180
- clock.labels<-paste(0:23,"00",sep="")
- clock.label.pos<-seq(5*pi/2,7*pi/12,by=-pi/12)
- radial.plot(lengths,radial.pos,labels=clock.labels,
-  label.pos=clock.label.pos,rp.type=rp.type,...)
+ if(!radians) radial.pos<-pi*(450-clock.pos*15)/180
+ if(is.null(labels))
+  labels<-paste(0:23,"00",sep="")
+ if(is.null(label.pos))
+  label.pos<-seq(5*pi/2,7*pi/12,by=-pi/12)
+ else
+  if(!radians) label.pos<-pi*(450-clock.pos*15)/180
+ radial.plot(lengths,radial.pos,labels=labels,label.pos=label.pos,
+  rp.type=rp.type,...)
 }
 
 # plots data as radial lines or a polygon starting at the right and going
@@ -20,17 +26,17 @@ clock24.plot<-function(lengths,clock.pos,rp.type="r",...) {
 # angles should be given in 0-360 values, use radial.plot for radians
 # example: polar.plot(rnorm(20)+3,seq(90,280,by=10))
 
-polar.plot<-function(lengths,polar.pos,labels,label.pos,rp.type="r",...) {
+polar.plot<-function(lengths,polar.pos,labels=NULL,label.pos=NULL,
+ rp.type="r",...) {
+ 
  npos<-length(lengths)
  # if no positions are given, add the average distance between positions so that
  # the first and last line don't overlap
  if(missing(polar.pos)) radial.pos<-seq(0,(2-2/(npos+1))*pi,length=npos)
  else radial.pos<-pi*polar.pos/180
- if(!missing(label.pos)) label.pos<-pi*label.pos/180
- if(missing(labels)) {
-  labels<-as.character(seq(0,340,by=20))
-  label.pos<-seq(0,1.89*pi,length=18)
- }
+ if(is.null(label.pos)) label.pos<-seq(0,1.89*pi,length=18)
+ else label.pos<-pi*label.pos/180
+ if(is.null(labels)) labels<-as.character(seq(0,340,by=20))
  radial.plot(lengths,radial.pos,labels,label.pos,rp.type=rp.type,...)
 }
 
@@ -40,11 +46,10 @@ polar.plot<-function(lengths,polar.pos,labels,label.pos,rp.type="r",...) {
 # label.prop is the proportion of max(lengths) that gives the
 # radial position of the labels
 
-radial.plot<-function(lengths,radial.pos,labels,label.pos,
- rp.type="r",label.prop=1.1,main="",xlab="",ylab="",line.col=par("fg"),
- mar=c(2,2,3,2),show.grid=TRUE,show.radial.grid=TRUE,grid.col="gray",
- grid.bg="transparent",point.symbols=NULL,point.col=NULL,
- show.centroid=FALSE,radial.lim=NULL,...) {
+radial.plot<-function(lengths,radial.pos,labels,label.pos,rp.type="r",
+ label.prop=1.1,main="",xlab="",ylab="",line.col=par("fg"),mar=c(2,2,3,2),
+ show.grid=TRUE,show.radial.grid=TRUE,grid.col="gray",grid.bg="transparent",
+ point.symbols=NULL,point.col=NULL,show.centroid=FALSE,radial.lim=NULL,...) {
  
  length.dim<-dim(lengths)
  if(is.null(radial.lim)) radial.lim<-range(lengths)
@@ -74,7 +79,7 @@ radial.plot<-function(lengths,radial.pos,labels,label.pos,
   grid.pos<-NA
   maxlength<-max(radial.lim)
  }
- oldpar<-par(no.readonly=TRUE)
+ oldpar<-par("xpd","mar","pty")
  par(mar=mar,pty="s")
  plot(c(-maxlength,maxlength),c(-maxlength,maxlength),type="n",axes=FALSE,
   main=main,xlab=xlab,ylab=ylab,...)
